@@ -56,22 +56,6 @@
 #endif
 
 
-// Define ens_deprecated for deprecated functionality.
-// This is adapted from Armadillo's implementation.
-#if defined(_MSC_VER)
-  #define ens_deprecated __declspec(deprecated)
-#elif defined(__GNUG__) && (!defined(__clang__))
-  #define ens_deprecated __attribute__((__deprecated__))
-#elif defined(__clang__)
-  #if __has_attribute(__deprecated__)
-    #define ens_deprecated __attribute__((__deprecated__))
-  #else
-    #define ens_deprecated
-  #endif
-#else
-  #define ens_deprecated
-#endif
-
 // undefine conflicting macros
 #if defined(As)
   #pragma message ("WARNING: undefined conflicting 'As' macro")
